numpy.nditer
============

.. currentmodule:: numpy

.. autoclass:: nditer

   

   .. HACK
      .. autosummary::
         :toctree:
      
         nditer.__init__
         nditer.copy
         nditer.debug_print
         nditer.enable_external_loop
         nditer.iternext
         nditer.next
         nditer.remove_axis
         nditer.remove_multi_index
         nditer.reset



   

   .. HACK
      .. autosummary::
         :toctree:
      
         nditer.dtypes
         nditer.finished
         nditer.has_delayed_bufalloc
         nditer.has_index
         nditer.has_multi_index
         nditer.index
         nditer.iterationneedsapi
         nditer.iterindex
         nditer.iterrange
         nditer.itersize
         nditer.itviews
         nditer.multi_index
         nditer.ndim
         nditer.nop
         nditer.operands
         nditer.shape
         nditer.value

